#ifndef FLYFILEDIALOG_H
#define FLYFILEDIALOG_H

#include "ifiledialog.h"
#include "flyfiledialog_global.h"

class FLY_FILEDIALOG_EXPORT FlyFileDialog : public QObject, public LibFlyFileDialog::IFileDialog
{
    Q_OBJECT
public:
    explicit FlyFileDialog(QWidget *parent = 0,
                           const QString &caption = QString(),
                           const QString &directory = QString(),
                           const QString &filter = QString());

    ~FlyFileDialog();

    void setDirectory(const QString &directory) Q_DECL_OVERRIDE;
    QString directory() const Q_DECL_OVERRIDE;

    void selectFile(const QString &filename) Q_DECL_OVERRIDE;
    QStringList selectedFiles() const Q_DECL_OVERRIDE;

    void setNameFilter(const QString &filter) Q_DECL_OVERRIDE;
    void setNameFilters(const QStringList& filters) Q_DECL_OVERRIDE;
    void selectNameFilter(const QString &filter) Q_DECL_OVERRIDE;
    QString selectedNameFilter() const Q_DECL_OVERRIDE;

    QDir::Filters filter() const Q_DECL_OVERRIDE;
    void setFilter(QDir::Filters filters) Q_DECL_OVERRIDE;

    void setViewMode(QFileDialog::ViewMode mode) Q_DECL_OVERRIDE;
    QFileDialog::ViewMode viewMode() const Q_DECL_OVERRIDE;

    void setFileMode(QFileDialog::FileMode mode) Q_DECL_OVERRIDE;
    QFileDialog::FileMode fileMode() const Q_DECL_OVERRIDE;

    void setAcceptMode(QFileDialog::AcceptMode mode) Q_DECL_OVERRIDE;
    QFileDialog::AcceptMode acceptMode() const Q_DECL_OVERRIDE;

    void setConfirmOverwrite(bool enabled) Q_DECL_OVERRIDE;
    bool confirmOverwrite() const Q_DECL_OVERRIDE;

    void setDefaultSuffix(const QString &suffix) Q_DECL_OVERRIDE;
    QString defaultSuffix() const Q_DECL_OVERRIDE;

    void setSidebarUrls(const QList<QUrl> & urls) Q_DECL_OVERRIDE;
    QList<QUrl> sidebarUrls() const Q_DECL_OVERRIDE;

    void setVisible(bool visible) Q_DECL_OVERRIDE;

    void setShowOptions(Qt::WindowFlags windowFlags,
                        Qt::WindowModality windowModality,
                        QWindow *parent) Q_DECL_OVERRIDE;

    static QString getOpenFileName(QWidget *parent = 0,
                                   const QString &caption = QString(),
                                   const QString &dir = QString(),
                                   const QString &filter = QString(),
                                   QString *selectedFilter = 0);

    static QString getSaveFileName(QWidget *parent = 0,
                                   const QString &caption = QString(),
                                   const QString &dir = QString(),
                                   const QString &filter = QString(),
                                   QString *selectedFilter = 0);

    static QString getExistingDirectory(QWidget *parent = 0,
                                        const QString &caption = QString(),
                                        const QString &dir = QString());

    static QStringList getOpenFileNames(QWidget *parent = 0,
                                        const QString &caption = QString(),
                                        const QString &dir = QString(),
                                        const QString &filter = QString(),
                                        QString *selectedFilter = 0);

    QString windowTitle() const Q_DECL_OVERRIDE;

public Q_SLOTS:
    void setWindowTitle(const QString &) Q_DECL_OVERRIDE;
    int exec() Q_DECL_OVERRIDE;

Q_SIGNALS:
    void currentUrlChanged(const QUrl & url);
    void directoryUrlEntered(const QUrl & directory);
    void urlSelected(const QUrl & url);
    void urlsSelected(const QList<QUrl> & urls);
    void filterSelected(const QString & filter);
    void accepted();
    void rejected();

private:
    static LibFlyFileDialog::IFileDialog* createFileDialog(QWidget *parent = 0);
    LibFlyFileDialog::IFileDialog* fileDialog;
};

#endif
